@@ -56,11 +56,11 @@ docdb_update.src_couchdb <- function(src, key, value, query, ...) {
   input <- jsonify::to_ndjson(input)
 
   # data frame to json
-  if (isa(value, "data.frame")) {
+  if (all(class(value) %in% "data.frame")) {
     value <- jsonify::to_json(value, by = "col", unbox = TRUE)
   }
   # list to json
-  if (isa(value, "list")) {
+  if (all(class(value) %in% "list")) {
     value <- jsonify::to_json(value, unbox = TRUE)
   }
 
@@ -98,12 +98,12 @@ docdb_update.src_elastic <- function(src, key, value, query, ...) {
   if (!length(ids)) return(0L)
 
   # json to data frame
-  if (isa(value, "character")) {
+  if (all(class(value) %in% "character")) {
     value <- jsonlite::fromJSON(value)
   }
 
   # list to data frame
-  if (isa(value, "list")) {
+  if (all(class(value) %in% "list")) {
     value <- jsonlite::fromJSON(
       jsonlite::toJSON(value, auto_unbox = TRUE))
     # if value is still simple list
@@ -177,11 +177,11 @@ docdb_update.src_mongo <- function(src, key, value, query, ...) {
   # process value, target is json string
 
   # data frame to json
-  if (isa(value, "data.frame")) {
+  if (all(class(value) %in% "data.frame")) {
     value <- jsonify::to_json(value, by = "col", unbox = TRUE)
   }
   # list to json
-  if (isa(value, "list")) {
+  if (all(class(value) %in% "list")) {
     value <- jsonify::to_json(value, unbox = TRUE)
   }
 
@@ -219,11 +219,11 @@ docdb_update.src_mongo <- function(src, key, value, query, ...) {
 docdb_update.src_sqlite <- function(src, key, value, query, ...) {
 
   # data frame to json
-  if (isa(value, "data.frame")) {
+  if (all(class(value) %in% "data.frame")) {
     value <- jsonify::to_json(value, by = "col", unbox = TRUE)
   }
   # list to json
-  if (isa(value, "list")) {
+  if (all(class(value) %in% "list")) {
     value <- jsonify::to_json(value, unbox = TRUE)
   }
 
@@ -257,11 +257,11 @@ docdb_update.src_sqlite <- function(src, key, value, query, ...) {
 docdb_update.src_postgres <- function(src, key, value, query, ...) {
 
   # data frame to json
-  if (isa(value, "data.frame")) {
+  if (all(class(value) %in% "data.frame")) {
     value <- jsonify::to_json(value, by = "col", unbox = TRUE)
   }
   # list to json
-  if (isa(value, "list")) {
+  if (all(class(value) %in% "list")) {
     value <- jsonify::to_json(value, unbox = TRUE)
   }
 
